@@ -41,26 +41,40 @@ impl SpecialOps<TypedFact, Box<dyn TypedOp>> for TypedModel {
     ) -> TractResult<TVec<OutletId>> {
         let op = op.into();
         let name = name.into();
-        let output_facts = {
-            let input_facts =
-                inputs.iter().map(|o| self.outlet_fact(*o)).collect::<TractResult<TVec<_>>>()?;
-            if input_facts.iter().all(|f| f.konst.is_some()) && op.is_stateless() {
-                let tensors =
-                    input_facts.iter().map(|f| f.konst.clone().unwrap()).collect::<TVec<_>>();
-                let outputs =
-                    op.eval(tensors).with_context(|| format!("Eager eval of {} {:?}", name, op))?;
-                outputs.into_iter().map(|t| TypedFact::from(t)).collect()
-            } else {
-                op.output_facts(&*input_facts)
-                    .with_context(|| format!("wiring {} ({:?})", name, op))?
-            }
-        };
-        let id = self.add_node(name, op, output_facts)?;
-        inputs
-            .iter()
-            .enumerate()
-            .try_for_each(|(ix, i)| self.add_edge(*i, InletId::new(id, ix)))?;
-        Ok(self.node(id).outputs.iter().enumerate().map(|(ix, _)| OutletId::new(id, ix)).collect())
+
+        {
+            let output_facts = || {
+                let input_facts = inputs
+                    .iter()
+                    .map(|o| self.outlet_fact(*o))
+                    .collect::<TractResult<TVec<_>>>()?;
+                if input_facts.iter().all(|f| f.konst.is_some()) && op.is_stateless() {
+                    let tensors =
+                        input_facts.iter().map(|f| f.konst.clone().unwrap()).collect::<TVec<_>>();
+                    if let Ok(outputs) = op.eval(tensors) {
+                        return Ok(outputs.into_iter().map(|t| TypedFact::from(t)).collect());
+                    }
+                }
+                op.output_facts(&*input_facts).context("in output_facts invocation")
+            };
+
+            let output_facts = output_facts()
+                .with_context(|| format!("wiring {} ({:?}), determining output_facts", name, op))?;
+            let id = self.add_node(&name, &op, output_facts)?;
+            inputs
+                .iter()
+                .enumerate()
+                .try_for_each(|(ix, i)| self.add_edge(*i, InletId::new(id, ix)))?;
+            TractResult::Ok(
+                self.node(id)
+                    .outputs
+                    .iter()
+                    .enumerate()
+                    .map(|(ix, _)| OutletId::new(id, ix))
+                    .collect(),
+            )
+        }
+        .with_context(|| format!("Wiring node \"{}\", {:?}", name, op))
     }
 }
 
@@ -72,8 +86,10 @@ impl TypedModel {
         hasher.finish()
     }
 
-    pub fn into_optimized(self) -> TractResult<TypedModel> {
-        self.declutter()?.optimize()
+    pub fn into_optimized(mut self) -> TractResult<TypedModel> {
+        self.declutter()?;
+        self.optimize()?;
+        Ok(self)
     }
 
     #[cfg(all(debug_assertions, feature = "paranoid_assertions"))]
@@ -115,9 +131,14 @@ impl TypedModel {
         Ok(())
     }
 
+    pub fn into_decluttered(mut self) -> TractResult<TypedModel> {
+        self.declutter()?;
+        Ok(self)
+    }
+
     /// Perform declutter passes on the network.
-    pub fn declutter(&self) -> TractResult<TypedModel> {
-        crate::optim::Optimizer::declutter().optimize(&self)
+    pub fn declutter(&mut self) -> TractResult<()> {
+        crate::optim::Optimizer::declutter().optimize(self)
     }
 
     pub fn concretize_dims(&self, values: &SymbolValues) -> TractResult<TypedModel> {
@@ -137,8 +158,8 @@ impl TypedModel {
     }
 
     /// Translate the graph to locally optimized operators (LIR or MIR ops).
-    pub fn optimize(self) -> TractResult<TypedModel> {
-        crate::optim::Optimizer::codegen().optimize(&self)
+    pub fn optimize(&mut self) -> TractResult<()> {
+        crate::optim::Optimizer::codegen().optimize(self)
     }
 
     pub fn invariants(&self) -> TractResult<invariants::Invariants> {
